@@ -358,21 +358,39 @@ sub abs2rel {
 
     for ($path, $base) { $_ = $self->canonpath($_) }
 
+    if (grep $self->file_name_is_absolute($_), $path, $base) {
+	for ($path, $base) { $_ = $self->rel2abs($_) }
+    }
+    else {
+	# save a couple of cwd()s if both paths are relative
+	for ($path, $base) { $_ = $self->catdir('/', $_) }
+    }
+
     my ($path_volume) = $self->splitpath($path, 1);
     my ($base_volume) = $self->splitpath($base, 1);
 
     # Can't relativize across volumes
     return $path unless $path_volume eq $base_volume;
 
-    for ($path, $base) { $_ = $self->rel2abs($_) }
-
     my $path_directories = ($self->splitpath($path, 1))[1];
     my $base_directories = ($self->splitpath($base, 1))[1];
 
+    # For UNC paths, the user might give a volume like //foo/bar that
+    # strictly speaking has no directory portion.  Treat it as if it
+    # had the root directory for that volume.
+    if (!length($base_directories) and $self->file_name_is_absolute($base)) {
+      $base_directories = $self->rootdir;
+    }
+
     # Now, remove all leading components that are the same
     my @pathchunks = $self->splitdir( $path_directories );
     my @basechunks = $self->splitdir( $base_directories );
 
+    if ($base_directories eq $self->rootdir) {
+      shift @pathchunks;
+      return $self->canonpath( $self->catpath('', $self->catdir( @pathchunks ), '') );
+    }
+
     while (@pathchunks && @basechunks && $self->_same($pathchunks[0], $basechunks[0])) {
         shift @pathchunks ;
         shift @basechunks ;
@@ -471,6 +489,7 @@ sub _collapse {
 
     my($vol, $dirs, $file) = $fs->splitpath($path);
     my @dirs = $fs->splitdir($dirs);
+    pop @dirs if @dirs && $dirs[-1] eq '';
 
     my @collapsed;
     foreach my $dir (@dirs) {
